[gimp] plug-ins: use list() variants in bindings.



commit 69f6f5748a2bd177b49af1a0c6df669c286f49cf
Author: Jehan <jehan girinstud io>
Date:   Mon Jun 27 22:30:42 2022 +0200

    plug-ins: use list() variants in bindings.
    
    Cf. previous commit.

 plug-ins/python/file-openraster.py | 4 ++--
 plug-ins/python/spyro-plus.py      | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/plug-ins/python/file-openraster.py b/plug-ins/python/file-openraster.py
index 20e0bbe83c..3063239925 100755
--- a/plug-ins/python/file-openraster.py
+++ b/plug-ins/python/file-openraster.py
@@ -273,7 +273,7 @@ def save_ora(procedure, run_mode, image, n_drawables, drawables, file, args, dat
                 yield layer
             else:
                 yield layer
-                for sublayer in enumerate_layers(layer.get_children()):
+                for sublayer in enumerate_layers(layer.list_children()):
                     yield sublayer
                 yield NESTED_STACK_END
 
@@ -281,7 +281,7 @@ def save_ora(procedure, run_mode, image, n_drawables, drawables, file, args, dat
     parent_groups = []
     i = 0
 
-    layer_stack = image.get_layers()
+    layer_stack = image.list_layers()
     # Number of top level layers for tracking progress
     lay_cnt = len(layer_stack)
 
diff --git a/plug-ins/python/spyro-plus.py b/plug-ins/python/spyro-plus.py
index 3f1b8a1c25..d4661c7b04 100755
--- a/plug-ins/python/spyro-plus.py
+++ b/plug-ins/python/spyro-plus.py
@@ -379,13 +379,13 @@ class SelectionToPath:
             GObject.Value(Gimp.RunMode, Gimp.RunMode.NONINTERACTIVE),
             GObject.Value(Gimp.Image, self.image),
             GObject.Value(GObject.TYPE_INT, 0),
             # XXX: I could use self.image.get_selected_layers() but for
             # this call, it doesn't matter anyway.
             GObject.Value(Gimp.ObjectArray,
                           Gimp.ObjectArray.new(Gimp.Drawable, [], False)),
         ])
 
-        self.path = self.image.get_vectors()[0]
+        self.path = self.image.list_vectors()[0]
         self.stroke_ids = self.path.get_strokes()
 
         # A path may contain several strokes. If so lets throw away a stroke that
@@ -379,13 +379,13 @@ class SelectionToPath:
             GObject.Value(Gimp.Image, self.image),
             GObject.Value(GObject.TYPE_INT, 0),
-            # XXX: I could use self.image.get_selected_layers() but for
+            # XXX: I could use self.image.list_selected_layers() but for
             # this call, it doesn't matter anyway.
             GObject.Value(Gimp.ObjectArray,


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]